Module error

Module error 

Structs

BasicParseError
The fundamental parsing errors that can be triggered by built-in parsing routines.
Err
An error with a source location.
ErrorLocation
A line and column location within a source file.
ErrorWithLocation
ParseError
Extensible parse errors that can be encountered by client parsing implementations.

Enums

BasicParseErrorKind
Details about a BasicParseError
MinifyErr
MinifyErrorKind
A transformation error.
ParserError
A parser error.
ParserErrorKind
PrinterErrorKind
A printer error type.
SelectorError
A selector parsing error.

Functions

fmt_printer_error

Type Aliases

MinifyError
PrinterError
A printer error.