SelectorError

Enum SelectorError 

pub enum SelectorError {
Show 21 variants bad_value_in_attr(Token), class_needs_ident(Token), dangling_combinator, empty_selector, expected_bar_in_attr(Token), expected_namespace(*const [u8]), explicit_namespace_unexpected_token(Token), invalid_pseudo_class_after_pseudo_element, invalid_pseudo_class_after_webkit_scrollbar, invalid_pseudo_class_before_webkit_scrollbar, invalid_qual_name_in_attr(Token), invalid_state, missing_nesting_prefix, missing_nesting_selector, no_qualified_name_in_attribute_selector(Token), pseudo_element_expected_ident(Token), unexpected_ident(*const [u8]), unexpected_token_in_attribute_selector(Token), unsupported_pseudo_class_or_element(*const [u8]), unexpected_selector_after_pseudo_element(Token), ambiguous_css_module_class(*const [u8]),
}
A selector parsing error.

Variants



bad_value_in_attr(Token)

An unexpected token was found in an attribute selector.



class_needs_ident(Token)

An unexpected token was found in a class selector.



dangling_combinator

A dangling combinator was found.



empty_selector

An empty selector.



expected_bar_in_attr(Token)

A | was expected in an attribute selector.



expected_namespace(*const [u8])

A namespace was expected.



explicit_namespace_unexpected_token(Token)

An unexpected token was encountered in a namespace.



invalid_pseudo_class_after_pseudo_element

An invalid pseudo class was encountered after a pseudo element.



invalid_pseudo_class_after_webkit_scrollbar

An invalid pseudo class was encountered after a -webkit-scrollbar pseudo element.



invalid_pseudo_class_before_webkit_scrollbar

A -webkit-scrollbar state was encountered before a -webkit-scrollbar pseudo element.



invalid_qual_name_in_attr(Token)

Invalid qualified name in attribute selector.



invalid_state

The current token is not allowed in this state.



missing_nesting_prefix

The selector is required to have the & nesting selector at the start.



missing_nesting_selector

The selector is missing a & nesting selector.



no_qualified_name_in_attribute_selector(Token)

No qualified name in attribute selector.



pseudo_element_expected_ident(Token)

An invalid token was encountered in a pseudo element.



unexpected_ident(*const [u8])

An unexpected identifier was encountered.



unexpected_token_in_attribute_selector(Token)

An unexpected token was encountered inside an attribute selector.



unsupported_pseudo_class_or_element(*const [u8])

An unsupported pseudo class or pseudo element was encountered.



unexpected_selector_after_pseudo_element(Token)



ambiguous_css_module_class(*const [u8])