pub enum PrinterErrorKind {
ambiguous_url_in_custom_property {
url: *const [u8],
},
fmt_error,
invalid_composes_nesting,
invalid_composes_selector,
invalid_css_modules_pattern_in_grid,
maximum_nesting_expansion,
no_import_records,
}Expand description
A printer error type.
Variants
ambiguous_url_in_custom_property
An ambiguous relative url() was encountered in a custom property declaration.
fmt_error
A std::fmt::Error was encountered in the underlying destination.
invalid_composes_nesting
The CSS modules composes property cannot be used within nested rules.
invalid_composes_selector
The CSS modules composes property cannot be used with a simple class selector.
invalid_css_modules_pattern_in_grid
The CSS modules pattern must end with [local] for use in CSS grid.
maximum_nesting_expansion
Substituting parent selectors for & while compiling CSS nesting for
the configured targets exceeded the expansion limit.
no_import_records